@@ -1,5 +1,5 @@
 ;;;; prime-enum-mode.el: Description about selection by typing of numbers.
-;;;; $Id: prime-enum-mode.el,v 1.2 2004/02/29 12:38:33 komatsu Exp $
+;;;; $Id: prime-enum-mode.el,v 1.3 2004/03/30 21:20:28 komatsu Exp $
 ;;;;
 ;;;; Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ;;;;     All rights reserved.
@@ -54,9 +54,6 @@ nil $B$N>l9g$O(B prime-enum-char-list $B$NCM$,B3$/8B$j(B, prime-enum-mode $
   )
   
 ;;;; ------------------------------------------------------------
-(and (not (eq prime-style-display-candidates 'compact))
-     prime-conv-mode)
-
 (defun prime-enum-keyin (char)
   (if (and prime-enum-mode
 	   (not prime-enum-mode-ignorep)
