@@ -1,5 +1,5 @@
 ;;;; prime-init.el: initialize prime-el
-;;;; $Id: prime-init.el,v 1.12 2004/03/19 17:56:09 komatsu Exp $
+;;;; $Id: prime-init.el,v 1.15 2004/12/11 07:53:45 komatsu Exp $
 ;;;; 
 ;;;; Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ;;;;     All rights reserved.
@@ -23,14 +23,12 @@
 (require 'prime-enum-mode)
 (require 'prime-socialite)
 (require 'prime-log)
-(require 'prime-suikyo)
 
 (defun prime-init (&optional forcep)
   (prime-init-load-file)
   (prime-keymap-init forcep)
   (prime-mode-init forcep)
   (prime-server-init forcep)
-  (prime-suikyo-init forcep)
   (prime-style-init prime-style)
 
   (run-hooks 'prime-init-hook)
@@ -74,9 +72,13 @@
 	(define-key map " "     'prime-fund-convert-region)
 	(define-key map "\C-cw" 'prime-register)
 	(define-key map "\C-cc" 'prime-language-toggle)
-	(define-key map "\C-ce" 'prime-engine-select)
 	(define-key map "\M-\[" 'prime-fund-insparens-insert-parens)
 	(define-key map "\M-\]" 'prime-fund-insparens-insert-parens-reverse)
+	(define-key map [f6]    'prime-input-set-mode-hiragana)
+	(define-key map [f7]    'prime-input-set-mode-katakana)
+	(define-key map [f8]    'prime-input-set-mode-halfkatakana)
+	(define-key map [f9]    'prime-input-set-mode-wideascii)
+	(define-key map [f10]   'prime-input-set-mode-ascii)
 	(setq prime-fund-mode-map map)))
   ;; $BF~NOCf$N%-!<%^%C%W$N@_Dj(B
   (or (or prime-input-mode-map forcep)
@@ -124,19 +126,20 @@
 	(define-key map "\C- " 'prime-space)
 	(define-key map "\M- " 'prime-space)
 ;	(define-key map "\177" 'prime-undo)
-	(define-key map "\C-k" 'prime-conv-katakana)
-	(define-key map "\M-k" 'prime-conv-katakana)
-	(define-key map "\M-h" 'prime-conv-hiragana)
-	(define-key map "\M-l" 'prime-conv-ascii)
+	(define-key map "\C-k" 'prime-input-set-mode-katakana)
+	(define-key map "\M-k" 'prime-input-set-mode-katakana)
+	(define-key map "\M-h" 'prime-input-set-mode-hiragana)
+	(define-key map "\M-l" 'prime-input-set-mode-ascii)
 	(define-key map "\C-s" 'prime-narrow-mode)
 	(define-key map "\C-cc" 'prime-language-toggle)
-	(define-key map "\C-ce" 'prime-engine-select)
-	(define-key map [muhenkan]          'prime-conv-hiragana-without-learn)
+	(define-key map [muhenkan]    'prime-commit-preedition-without-learn)
 	(define-key map [henkan-mode]       'prime-conv-decide)
-	(define-key map [hiragana-katakana] 'prime-conv-katakana)
-	(define-key map [f6]                'prime-conv-hiragana)
-	(define-key map [f7]                'prime-conv-katakana)
-	(define-key map [f10]               'prime-conv-ascii)
+	(define-key map [hiragana-katakana] 'prime-input-set-mode-katakana)
+	(define-key map [f6]                'prime-input-set-mode-hiragana)
+	(define-key map [f7]                'prime-input-set-mode-katakana)
+	(define-key map [f8]                'prime-input-set-mode-halfkatakana)
+	(define-key map [f9]                'prime-input-set-mode-wideascii)
+	(define-key map [f10]               'prime-input-set-mode-ascii)
 	(if (featurep 'xemacs)
 	    (define-key map '(control ?.) 'prime-conv-exact)
 	  (define-key map [?\^.] 'prime-conv-exact))
