@@ -1,9 +1,5 @@
-(defvar prime-pat "")
-(make-variable-buffer-local 'prime-pat)
 (defvar prime-start-pat "" "convert-region $B$r%-%c%s%;%k$7$?;~$K85$KLa$9J8;zNs(B")
 (make-variable-buffer-local 'prime-start-pat)
-(defvar prime-pat-for-undo "")
-(make-variable-buffer-local 'prime-pat-for-undo)
 
 (defvar	prime-cands nil)
 (make-variable-buffer-local 'prime-cands)
@@ -24,10 +20,8 @@
 (make-variable-buffer-local 'prime-conv-mode-for-undo)
 
 ;; $BFbItJQ?t$NDj5A(B.
-;(defvar	prime-pat "") ; $B8!:w%Q%?%s(B
-;(make-variable-buffer-local 'prime-pat)
 (defvar	prime-prev-pattern nil 
-  "prime-pat $B$H$3$NCM$,F1$8$J$i$P%-%c%C%7%e$7$?8uJd$rMxMQ$9$k(B.")
+  "preedition $B$H$3$NCM$,F1$8$J$i$P%-%c%C%7%e$7$?8uJd$rMxMQ$9$k(B.")
 (make-variable-buffer-local 'prime-prev-pattern)
 (defvar	prime-next-pattern "")		; $B8!:w%Q%?%s(B
 (make-variable-buffer-local 'prime-next-pattern)
@@ -75,8 +69,6 @@
 (make-variable-buffer-local 'prime-modeline-original)
 (defvar prime-modeline-status "[PRIME]")
 (make-variable-buffer-local 'prime-modeline-status)
-(defvar prime-input-column 0)
-(make-variable-buffer-local 'prime-input-column)
 (defvar prime-tmp-fontify-region nil)
 (make-variable-buffer-local 'prime-tmp-fontify-region)
 (defvar prime-conv-exact-p nil "non nil $B$N>l9g(B, $BC14A;zJQ49%b!<%I(B")
@@ -104,8 +96,7 @@
 ;;;; $B=i4|2=MQ4X?t(B
 ;;;; ------------------------------------------------------------
 (defun prime-reset-pat ()
-  (setq prime-pat-for-undo prime-pat)
-  (setq prime-pat "")
+  (prime-input-erase)
   )
 
 (defun prime-reset-cands ()
@@ -146,13 +137,10 @@
       (prime-disp-narrow)))
    (prime-conv-mode
     (prime-conv-prev))
-   (t
-    (if (= (length prime-pat) 1)
-	(prime-conv-cancel-all)
-      (setq prime-pat (substring prime-pat 0 -1))
-      (setq prime-input-column (1- prime-input-column))
-      (prime-disp-input)
-      ))))
+   (t  ;; prime-input-mode
+    ;; Not implemented yet.
+    )
+   ))
 
 ;;;; ============================================================
 
@@ -236,7 +224,6 @@
   (prime-reset-pat)
   (setq prime-start-pat "")
   (setq prime-prev-pattern nil) ; $B8!:w%Q%?%s(B
-  (setq prime-input-column 0) ;; $B$3$3$G$b@_Dj$5$l$F$$$k$N$OIi$1(B.
   (prime-reset-cands)
   (prime-reset-nth-cand)
   (mell-marker-set 'prime-curstr-begin (point))
@@ -259,7 +246,7 @@
     ))
 
 (defun prime-disp-input (&optional pattern)
-  (setq pattern (or pattern prime-pat))
+  (setq pattern (or pattern (prime-input-get-inserting-label)))
   (prime-erase-curstr)
   (prime-disp-curstr)
 
@@ -275,7 +262,8 @@
   (prime-erase-cand-list)
   (prime-erase-curstr)
   (prime-disp-curstr)
-  (prime-disp-cand-list)
+  (if (> (length prime-cands) 0)
+      (prime-disp-cand-list))
   )
 
 (defun prime-disp-narrow (&optional nth)
@@ -314,38 +302,45 @@
 ;  (setq prime-curstr-end (point))
   )
 
-;; $BA*Br8uJd$rI=<((B
-;; $B1x$/$J$C$F$-$?(B. narrow-mode $B$OJ,$1$h$&(B.
-(defun prime-disp-curstr ()
-  (setq prime-curstr
-	(cond (prime-conv-mode
-	       (prime-nth-candidate prime-nth-cand))
-	      ;; prime-input-mode
-	      ((and (= prime-input-column (length prime-pat))
-		    (eq prime-language-default 'japanese))
-	       (or (prime-input-get-label) prime-pat))
-	      (t
-	       prime-pat)))
-  (mell-marker-set 'prime-curstr-begin (point))
-  (if prime-narrow-mode
-      (insert "[" prime-curstr "|" 
-	      (prime-get-hiragana prime-pat) "*" ;; $B%-%?%M!<(B, $B;`$L!<(B.
-	      (if (= prime-narrow-column (length prime-narrow-pat))
-		  (prime-get-hiragana prime-narrow-pat)
-		prime-narrow-pat)
-	      "]")
-    (insert "[" prime-curstr "]"))
-  (mell-marker-set 'prime-curstr-end (point))
+(defun prime-disp-get-curstr ()
+  (if prime-conv-mode
+      (list (prime-nth-candidate prime-nth-cand) "" "")
+    ;; prime-input-mode
+    (prime-input-get-label)))
 
-  (if prime-narrow-mode
-      (and (/= prime-narrow-column (length prime-narrow-pat))
-	   (backward-char (1+ (- (length prime-narrow-pat)
-				 prime-narrow-column))))
-    (and (not prime-conv-mode)
-	 (/= prime-input-column (length prime-pat))
-	 (backward-char (1+ (- (length prime-pat) prime-input-column))))
-    )
-  )
+;; $BA*Br8uJd$rI=<((B
+(defun prime-disp-curstr ()
+  (let* ((curstr (prime-disp-get-curstr))
+	 (backward-offset (+ (length (nth 1 curstr))
+			     (length (nth 2 curstr)))))
+    (setq prime-curstr (apply 'concat curstr))
+
+    (mell-marker-set 'prime-curstr-begin (point))
+    (insert "[" prime-curstr "]")
+    (mell-marker-set 'prime-curstr-end (point))
+
+    ;; Move the cursor backward to the correct position in the preedition.
+    (if (> backward-offset 0)
+	;; +1 means the length of "]"
+	(backward-char (1+ backward-offset)))
+
+    (prime-disp-annotation prime-curstr)
+    (prime-disp-usage      prime-curstr)
+  ))
+
+(defun prime-disp-annotation (literal)
+  "This displays an annotation for the word LITERAL"
+  (let ((annotation (prime-server-get-word-data literal "annotation")))
+    (if (and annotation (not (mell-buffer-minibuffer-p)))
+      (message annotation))
+    ))
+
+(defun prime-disp-usage (literal)
+  "This displays a usage comment for the word LITERAL"
+  (let ((usage (prime-server-get-word-data literal "usage")))
+    (if (and usage (not (mell-buffer-minibuffer-p)))
+	(message usage))
+    ))
 
 ;; $B8uJd%j%9%H$r%+!<%=%k$N(B1$B9T2<$KI=<((B
 (defun prime-disp-cand-list ()
@@ -451,25 +446,23 @@
   (prime-server-dict-register-word word pattern)
   )
 
-(defun prime-register-word (&optional pat)
+(defun prime-register-word (&optional reading)
   (interactive)
-  (setq pat (or pat prime-pat))
+  (setq reading (or reading (prime-input-get-inserting-label)))
   (let ((minibuffer-setup-hook (cons 'prime-mode-on minibuffer-setup-hook))
 	(prime-learn-p nil)
-	kana word)
-    (setq pron (prime-input-get-label pat))
-    (setq word (read-string (concat "[$BC18lEPO?(B] $B!V(B" pron "$B!W$NJQ49(B: ")))
-    (prime-server-dict-register-word word pron)
-    (prime-fix-without-learn word)
+	literal)
+    (setq literal (read-string (concat "[$BC18lEPO?(B] $B!V(B" reading "$B!W$NJQ49(B: ")))
+    (prime-server-dict-register-word literal reading)
+    (prime-fix-without-learn literal)
     (prime-fund-mode t)
-    )
-  )
+    ))
 
-(defun prime-get-nth (&optional word pattern)
+(defun prime-get-nth (&optional word)
   (if (not word)
       prime-nth-cand
-    (or pattern (setq pattern prime-pat))
-    (mell-list-member-get-nth word (prime-search pattern))
+    (mell-list-member-get-nth word
+			      (prime-search (prime-input-get-inserting-label)))
     ))
 
 (defun prime-fix (cand) ; $B8uJd$r(Bcand$B$K3NDj(B
@@ -490,24 +483,17 @@
   (prime-conv-mode-off)
   )
 
+
 (defun prime-after-fix (&optional next-char)
-  (if next-char
-      (if (= (length prime-next-pattern) 0)
-	  (setq prime-next-pattern (char-to-string next-char))
-	(if (not (string= (downcase (char-to-string next-char))
-			  (substring prime-next-pattern 0 1)))
-	    (setq prime-next-pattern (char-to-string next-char))
-	  )))
-  (if (or prime-predict-after-fix (> (length prime-next-pattern) 0))
-      (progn
-	(setq prime-pat prime-next-pattern)
-	(setq prime-next-pattern "")
-	(setq prime-input-column (length prime-pat))
-	(prime-input-mode-on)
-	(prime-disp-input))
-    (prime-fund-mode-on)
-    )
-  )
+  (cond
+   (next-char
+    (prime-input-mode-on)
+    (prime-input-insert-char next-char))
+   (prime-predict-after-fix
+    (prime-input-refresh))
+   (t
+    (prime-fund-mode-on))
+   ))
 
 (defun prime-insert (word)
   (let (undo-begin undo-end)
@@ -528,7 +514,8 @@
   (interactive)
   (if (y-or-n-p (concat prime-curstr " $B$r:o=|$7$^$9$+(B? "))
       (progn
-	(prime-server-dict-delete-word prime-curstr prime-pat)
+	(prime-server-dict-delete-word prime-curstr
+				       (prime-input-get-inserting-label))
 	(prime-conv-next))
     ))
 
@@ -566,30 +553,9 @@
 	 (prime-disp-conv)))
   )
 
-(defun prime-conv-ascii ()
+(defun prime-commit-preedition-without-learn ()
   (interactive)
-  (prime-fix prime-pat)
-  (prime-after-fix)
-  (prime-fund-mode-on)
-  )
-
-(defun prime-conv-hiragana ()
-  (interactive)
-  (prime-fix (prime-get-hiragana prime-pat))
-  (prime-after-fix)
-  (prime-fund-mode-on)
-  )
-
-(defun prime-conv-hiragana-without-learn ()
-  (interactive)
-  (prime-fix-without-learn (prime-get-hiragana prime-pat))
-  (prime-after-fix)
-  (prime-fund-mode-on)
-  )
-
-(defun prime-conv-katakana ()
-  (interactive)
-  (prime-fix (prime-get-katakana prime-pat))
+  (prime-fix-without-learn (prime-input-get-inserting-label))
   (prime-after-fix)
   (prime-fund-mode-on)
   )
@@ -620,15 +586,17 @@
     (string-match "^[A-Z]+$" input)))
 
 (defun prime-input-no-japanese-p (input)
-  (string-match "\\cj+[a-zA-Z-]+\\cj+\\|^[a-zA-Z-]*$"
-		(prime-get-hiragana input)))
+  (string-match "\\cj+[a-zA-Z-]+\\cj+\\|^[a-zA-Z-]*$" input))
 
 (defun prime-keyin-capital (char)
   ;; $BBgJ8;z$J$I$,F~NO$5$l$+$D(B, $BFbMF$,BEEv$J$i$P3NDj(B.
-  (if (and prime-fix-by-capital-p (>= char ?A) (<= char ?Z)
-	   (not (prime-input-no-japanese-p prime-pat))
-	   (not (prime-input-all-capital-p prime-pat))
-	   )
+  (if (and prime-fix-by-capital-p
+	   (>= char ?A)
+	   (<= char ?Z)
+	   (let ((preedition (prime-input-get-inserting-label))
+		 (query      (prime-input-get-query-string)))
+	     (and (not (prime-input-no-japanese-p preedition))
+		  (not (prime-input-all-capital-p query)))))
       (progn
 	(prime-fix prime-curstr)
 	(prime-after-fix char)
@@ -675,10 +643,9 @@
 
    ((prime-keyin-capital char))
 
-   (t ;; prime-fund-mode
+   (t ;; prime-fund-mode or prime-input-mode
     (prime-input-mode-on)
-    (prime-input-insert-char char)
-    (prime-disp-input))
+    (prime-input-insert-char char))
    ))
 
 (defalias 'prime-cand-keyin 'prime-keyin)
@@ -689,15 +656,6 @@
   (prime-fix prime-curstr)
   (prime-fund-mode-on)
   (insert " "))
-;; prime-space $B$=$N(B 2
-;  (if (> prime-nth-cand 0)
-;      (progn
-;	(prime-fix prime-curstr)
-;	(prime-fund-mode)
-;	(insert " "))
-;    (setq prime-pat (concat prime-pat " "))
-;    (prime-disp-input prime-pat)
-;    ))
 
 (provide 'prime-main)
 
