@@ -1,4 +1,4 @@
-;; $Id: prime-style.el,v 1.7 2004/03/19 17:56:09 komatsu Exp $
+;; $Id: prime-style.el,v 1.8 2004/03/30 05:44:30 komatsu Exp $
 
 (defcustom prime-style nil "PRIME $B$NF~NO%9%?%$%k(B
 'default, 'kana, 'tcode, 'capital-only, 'komatsu $B$+$iA*Br2DG=(B.
@@ -30,6 +30,10 @@ lookup-el, ebview $B$^$?$O(B nil $B$,;XDj2DG=$G$9!#(B")
 
 (defcustom prime-style-display-candidates 'compact
   "$BC18l8uJd$NI=<(J}K!(B (compact or all / default is compact)")
+(defcustom prime-style-display-candidates-compact 'default
+  "prime-style-display-candidates $B$,(B compact $B$N>l9g$N!":Y$+$$I=<(J}K!(B
+{default, always-number-selection}")
+
 
 (defun prime-style-init (&optional style)
   (setq style (or (and style (symbol-name style))
